Query

Struct Query 

pub struct Query {
    pub queryid: Option<QueryId>,
    pub node: Option<NodeName>,
    pub form: Option<DataForm>,
    pub set: Option<SetQuery>,
    pub flip_page: bool,
}
Starts a query to the archive.

Fields

queryid: Option<QueryId>

An optional identifier for matching forwarded messages to this query.

node: Option<NodeName>

Must be set to Some when querying a PubSub node’s archive.

form: Option<DataForm>

Used for filtering the results.

set: Option<SetQuery>

Used for paging through results.

flip_page: bool

Used for reversing the order of the results.